# $Date: 1996/12/13 11:43:06 $  $Author: tonner $  $Revision: 1.117.2.4 $ #
#
kg, 11.05.93

stdlib.mu -- lib-file for standard library STDLIB
#

proc()
    local path;
begin

#--
  If you need to use a local variable which is protected in the
  global context, you may use sysblock to push this variable on
  the stack, evaluate an expression and then pop the variable
  from the stack.
  
  Usage:
  
     stdlib::sysblock( var, expression )
  
--#
stdlib::sysblock := proc()
  option hold;
  local oldProtect;
begin
  oldProtect := protected(level(args(1),1), None);
  eval( subsop(hold(block(dummy, eval(args(2..args(0))))), 
               [1,1]=level(args(1),1))
  );
  protected(level(args(1),1), oldProtect);
  %2    
end_proc:

#--
  If a library routine often uses protected variables, these
  statements may be executed by syseval. 
  This routine is used by loadlib and loadproc, so it has to
  be defined before the first execution of both. 
  
  Usage:
  
     stdlib::syseval( expr )      

  !!! stdlib::syseval is used inside of loadproc. Do not move !!!!
--#
stdlib::syseval := 
proc()
  option hold;
  local oldProtect;
begin
  oldProtect := protected(hold(_assign), None);
  block(_assign, (
    sysassign(_assign, sysassign);
    eval(args());
  ));
  protected(hold(_assign), oldProtect);
  %2    
end_proc:


##
### Table of all library preferences with their  ###
### default values. Refer to the function 'pref' ###
### for further information.                     ###
##
stdlib::PREFTAB:= table(VerboseRead=0):

# VerboseRead -- preference to print information about 
		 loading packages and files

  VerboseRead = 0:  no information (default)
  VerboseRead = 1:  information about loading packages
  VerboseRead = 2:  information about loading packages and files
#


#--
  The following sets are used for the protect mechanism of the
  MuPAD library. The variables in stdlib::ENVIRONMENT_VARIABLES
  and stdlib::SYSTEM_CONSTANTS are not protected, the variables
  in stdlib::LIBRARY_CONSTANTS are protected.
  The protection is done at the end of .mupadsysinit.
--#
stdlib::ENVIRONMENT_VARIABLES:= {          
  hold(DIGITS), hold(ERRORLEVEL), hold(EVAL_STMT), hold(HISTORY), 
  hold(LEVEL), hold(LIB_PATH), hold(MAXDEPTH), hold(MAXLEVEL), 
  hold(ORDER), hold(PRETTY_PRINT), hold(PRINTLEVEL), hold(READ_PATH), 
  hold(SEED), hold(TEXTWIDTH), hold(WRITE_PATH), hold(procname),
  hold(TEST_PATH), hold(_mod)
}:


stdlib::SYSTEM_CONSTANTS := {
  hold(E), hold(EULER), hold(FALSE), hold(I), hold(PI), hold(TRUE), 
  hold(UNKNOWN)
}:   

stdlib::LIBRARY_CONSTANTS := { 
  hold(infinity), hold(MSDOS), hold(NO_CONVERGENCE), hold(NO_SOLUTION), 
  hold(toBeDefined), hold(UNBOUNDED), hold(undefined),
  hold(_dom_alias_element_), hold(complexInfinity)
}:



stdlib::TYPES := {           # used global in Types library #
  hold(ListOf), hold(ListOfIdents), hold(ListProduct), 
  hold(Laurent), hold(MatrixCat), hold(ODE), hold(PolyExpr), hold(PolyOf), 
  hold(Product), hold(RatExpr), hold(SequenceOf), hold(SetOf), 
  hold(TableOfEntry), hold(TableOfIndex), hold(Taylor), hold(Union)
}:


stdlib::OPTIONS := {
  hold(All), hold(Any), hold(Append), hold(Approx), hold(Axes), hold(Bin), 
  hold(CameraPoint), hold(Capacity), hold(Center), hold(Coeffs), hold(Color), 
  hold(Corner), hold(Scales), hold(Test),
  hold(Curve), hold(DegInvLexOrder), hold(Degree), hold(DegreeOrder), 
  hold(Diagonal), hold(Dimension), hold(Echo), hold(Error), hold(Eweight), 
  hold(Exact), hold(Expr), hold(Extended), hold(Filled), hold(FilledCircles), 
  hold(First),
  hold(FloatFormat), hold(Format), hold(Frames), hold(Frobenius), hold(Gif), 
  hold(Grid), 
  hold(Include), hold(Independent), hold(Index), hold(IndexList), hold(Infinity),
  hold(IntMod), hold(Labeling),
  hold(Labels), hold(Left), hold(left), hold(Length), hold(LexOrder), hold(line),
  hold(LineWidth), hold(List), hold(Maxmem), hold(Maxtime), hold(Mode),
  hold(move), hold(Multiple), hold(Name), hold(Named), hold(NonNested),
  hold(NonNegative), hold(None), hold(Open), hold(Path), hold(PlotDevice), 
  hold(PointStyle), hold(PointWidth), hold(pop), hold(PostMap), hold(PreMap), 
  hold(PrincipalValue), hold(Prompt), hold(PromptString), hold(push), 
  hold(Quiet), hold(Quo), hold(Raster), hold(CallBack), 
  hold(Rem), hold(Reorder), hold(Report), hold(Right), hold(right), hold(Root), 
  hold(Sample), hold(Scaling), 
  hold(Special), hold(Surface), hold(Term), hold(Terms), hold(Text), 
  hold(Title),  
  hold(UnConstrained), hold(Unique), hold(Unquoted), hold(Unrestricted),
  hold(User), 
  hold(Unsimplified), hold(Up), hold(VectorOf), hold(ViewingBox), 
  hold(Vweight), hold(Warning), hold(Write), hold(sincos),
  hold(X11), hold(Convex), hold(Concave), hold(RatExpr), hold(PolyExpr)
}:

stdlib::SYSTEM_TABLES := {
  hold(stdlib::Alias), hold(stdlib::LoadlibState), hold(stdlib::PREFTAB)
}:

path:= pathname("STDLIB"):

D:= loadproc(D, path, "D"):
evalassign:= loadproc(evalassign, path, "evalass"):
unassign:= loadproc(unassign, path, "unassign"):
export:= loadproc(export, path, "export"):
func:= loadproc(func, path, "func"):
fun:= loadproc(fun, path, "fun"):
info:= loadproc(info, path, "info"):
iquo:= loadproc(iquo, path, "iquo"):
irem:= loadproc(irem, path, "irem"):
plot2d:= loadproc(plot2d, path, "plot2d"):
plot3d:= loadproc(plot3d, path, "plot3d"):
profile:= loadproc(profile, path, "prof"):
random:= loadproc(random, path, "random"):
seq:= loadproc(seq, path, "seq"):
Poly:= loadproc(Poly, path, "Poly"):
O:= loadproc(O, path, "O"):
taylor:= loadproc(taylor, path, "taylor"):
gcd:= loadproc(gcd, path, "gcd"):
lcm:= loadproc(lcm, path, "lcm"):
content:= loadproc(content, path, "content"):
loadlib:= loadproc(loadlib, path, "loadlib"):
normal:= loadproc(normal, path, "normal"):
numer:= loadproc(numer, path, "numer"):
denom:= loadproc(denom, path, "denom"):
bernoulli:= loadproc(bernoulli, path, "bernoull"):
binomial:= loadproc(binomial, path, "binomial"):
fft:= loadproc(fft, path, "fft"):
ifft:= loadproc(ifft, path, "ifft"):
version:= loadproc(version, path, "version"):
factor:= loadproc(factor, path, "factor"):
sqrfree:= loadproc(sqrfree, path, "sqrfree"):
insert_ordered:= loadproc(insert_ordered, path, "ins_ord"):
resultant:= loadproc(resultant, path, "resultan"):
discrim:= loadproc(discrim, path, "discrim"):
linsert:= loadproc(linsert, path, "linsert"):
gcdex:= loadproc(gcdex, path, "gcdex"):
pdioe:= loadproc(pdioe, path, "pdioe"):
partfrac:= loadproc(partfrac, path, "partfrac"):
sum:= loadproc(sum, path, "sum"):
contfrac:= loadproc(contfrac, path, "contfrac"):
series:= loadproc(series, path, "series"):
limit:= loadproc(limit, path, "limit"):
powermod:= loadproc(powermod, path, "powermod"):
primpart:= loadproc(primpart, path, "primpart"):
infinity:= loadproc(infinity, path, "infinity"):
undefined:= loadproc(undefined, path, "undef"):
complexInfinity:= loadproc(complexInfinity, path, "cinfty"):
Factor:= loadproc(Factor, path, "factor"):
collect:= loadproc(collect, path, "collect"):
length:= loadproc(length, path, "length"):
stdlib::length:= loadproc(stdlib::length, path, "length"):
int:= loadproc(int, path, "int"):
maprat:= loadproc(maprat, path, "maprat"):
userinfo:= loadproc(userinfo, path, "userinfo"):
setuserinfo:= loadproc(setuserinfo, path, "setuinfo"):
expose:= loadproc(expose, path, "expose"):
radsimp:= loadproc(radsimp, path, "radsimp"):
combine:= loadproc(combine, path, "combine"):
decompose:= loadproc(decompose, path, "decomp"):
linsolve:= loadproc(linsolve, path, "linsolve"):
alias:= loadproc(alias, path, "alias"):
unalias:= loadproc(unalias, path, "unalias"):
RootOf := loadproc(RootOf, path, "RootOf"):
revert := loadproc(revert, path, "revert"):
rationalize := loadproc(rationalize, path, "maprat"):
randpoly := loadproc(randpoly, path, "randpoly"):
algsolve:= loadproc(algsolve,path,"algsolve"):
read:= loadproc(read, path, "read"):
maprec:= loadproc(maprec, path, "maprec"):
breakmap:= loadproc(breakmap, path, "maprec"):
asympt:= loadproc(asympt, path, "asympt"):
lazy_and:= loadproc(lazy_and, path, "lazy_and"):
_seqin:= loadproc(_seqin, path, "seqin"):
irreducible:= loadproc(irreducible, path, "irreduc"):
rewrite:= loadproc(rewrite, path, "rewrite"):
discont:= loadproc(discont, path, "discont"):
plotfunc:= loadproc(plotfunc, path, "plotfunc"):
assign:= loadproc(assign, path, "assign"):
# to be removed when the assume library works #
is:= loadproc(is, path, "is"):
assume:= loadproc(assume, path, "is"):
hastype:= loadproc(hastype, path, "hastype"):
optimize:= loadproc(optimize, path, "optimize"):
ithprime:=loadproc(ithprime, path, "ithprime"):
conjugate:= loadproc(conjugate, pathname("STDLIB","CONJ"), "conj"):
simplify:= loadproc(simplify, pathname("STDLIB","SIMPLIFY"), "simplify"):
rectform:= loadproc(rectform, pathname("STDLIB","RECTFORM"), "rectform"):
Re:= loadproc(Re, pathname("STDLIB","RE"), "Re"):
Im:= loadproc(Im, pathname("STDLIB","IM"), "Im"):
changevar:= loadproc(changevar, path, "changevr"):
product:= loadproc(product, path, "product"):
poly2list:= loadproc(poly2list, path, "poly2lst"):

#-- 
    New self-defined operators:

    @@ - repeated composition
    -> - functional operator

--#

bin_op("@@", repcom):
repcom := loadproc(repcom, path, "repcom"):

bin_op("->", arrow):
arrow := loadproc(arrow, path, "arrow"):


#-- Preferences --#
#pref:=  loadproc(pref, path, "pref"):#
pref(NIL):

#--
   solve -- solve equations and algebraic equations
--#

path:= pathname("STDLIB","SOLVE"):

solve                  := loadproc(solve,                  path,"solve"):
stdlib::solve_algebraic:= loadproc(stdlib::solve_algebraic,path,"algebr"):
stdlib::solve_eq       := loadproc(stdlib::solve_eq,       path,"equation"):
stdlib::solve_isalgebraic:= loadproc(stdlib::solve_isalgebraic,path,"isalgeb"):
stdlib::solve_islinear := loadproc(stdlib::solve_islinear, path,"islin"):
stdlib::isolate        := loadproc(stdlib::isolate,        path,"isolate"):
stdlib::solve_poly_irred:= loadproc(stdlib::solve_poly_irred,path,"pirred"):
stdlib::solve_poly     := loadproc(stdlib::solve_poly,     path,"poly"):
stdlib::solve_poly3    := loadproc(stdlib::solve_poly3,    path,"poly3"):
stdlib::solve_poly4    := loadproc(stdlib::solve_poly4,    path,"poly4"):
stdlib::solve_sys      := loadproc(stdlib::solve_sys,      path,"system"):
stdlib::ineqs          := loadproc(stdlib::ineqs,          path,"ineqs"):

protect   := fun( protected(args(1), Warning), hold ):
unprotect := fun( protected(args(1),    None), hold ):

stdlib::LoadlibState["stdlib"]:= TRUE:

end_proc():

# end of file #
